@@ -76,6 +76,7 @@ class Window(Gtk.ApplicationWindow):
 
         self.prev_view = None
         self.curr_view = None
+        self.pl_todelete_notification = None
 
         size_setting = self.settings.get_value('window-size')
         if isinstance(size_setting[0], int) and isinstance(size_setting[1], int):
@@ -204,7 +205,7 @@ class Window(Gtk.ApplicationWindow):
         cursor = None
 
         Query()
-        if Query.music_folder and Query.download_folder:
+        if Query.music_folder:
             try:
                 cursor = tracker.query(Query.all_songs_count(), None)
                 if cursor is not None and cursor.next(None):
@@ -320,6 +321,11 @@ class Window(Gtk.ApplicationWindow):
         self.toolbar._selection_menu_label.set_text(_("Click on items to select them"))
         self._stack.get_visible_child().queue_draw()
 
+    def _show_notification(self):
+        self.notification_handler = None
+        self.notification.show_all()
+        return False
+
     @log
     def _init_loading_notification(self):
         self.notification = Gd.Notification()
@@ -336,10 +342,15 @@ class Window(Gtk.ApplicationWindow):
         if self.notification_handler:
             GLib.Source.remove(self.notification_handler)
             self.notification_handler = None
-        self.notification_handler = GLib.timeout_add(1000, self.notification.show_all)
+        self.notification_handler = GLib.timeout_add(1000, self._show_notification)
 
     @log
     def _init_playlist_removal_notification(self):
+        if self.pl_todelete_notification:
+            self.views[3].really_delete = False
+            self.pl_todelete_notification.destroy()
+            Views.playlists.delete_playlist(self.views[3].pl_todelete)
+
         self.notification = Gd.Notification()
         self.notification.set_timeout(20)
 
@@ -355,14 +366,14 @@ class Window(Gtk.ApplicationWindow):
 
         self.notification.show_all()
         self._overlay.add_overlay(self.notification)
-
-        self.notification.deletion_index = self.views[3].current_playlist_index
+        self.pl_todelete_notification = self.notification
 
         self.notification.connect("dismissed", self._playlist_removal_notification_dismissed)
         undo_button.connect("clicked", self._undo_deletion)
 
     @log
     def _playlist_removal_notification_dismissed(self, widget):
+        self.pl_todelete_notification = None
         if self.views[3].really_delete:
             Views.playlists.delete_playlist(self.views[3].pl_todelete)
         else:
@@ -372,7 +383,7 @@ class Window(Gtk.ApplicationWindow):
     def _undo_deletion(self, widget):
         self.views[3].really_delete = False
         self.notification.dismiss()
-        self.views[3].undo_playlist_deletion(self.notification.deletion_index)
+        self.views[3].undo_playlist_deletion()
 
     @log
     def _on_key_press(self, widget, event):
@@ -456,7 +467,8 @@ class Window(Gtk.ApplicationWindow):
                 # We should get back to the view before the search
                 self._stack.set_visible_child(self.views[4].previous_view)
             elif (self.views[4].previous_view == self.views[0] and
-                 self.curr_view.get_visible_child() != self.curr_view._albumWidget):
+                 self.curr_view.get_visible_child() != self.curr_view._albumWidget and
+                 self.curr_view.get_visible_child() != self.curr_view._artistAlbumsWidget):
                 self._stack.set_visible_child(self.views[0])
 
             if self.toolbar._selectionMode:
